aboutsummaryrefslogtreecommitdiffstats
path: root/test/libjulia/Common.h
diff options
context:
space:
mode:
Diffstat (limited to 'test/libjulia/Common.h')
-rw-r--r--test/libjulia/Common.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/libjulia/Common.h b/test/libjulia/Common.h
index 1371101c..b9c3d2fb 100644
--- a/test/libjulia/Common.h
+++ b/test/libjulia/Common.h
@@ -16,7 +16,7 @@
*/
/**
* @date 2017
* Common functions the iulia tests.
*/
#pragma once
@@ -46,9 +46,9 @@ namespace test
void printErrors(solidity::ErrorList const& _errors, solidity::Scanner const& _scanner);
std::pair<std::shared_ptr<solidity::assembly::Block>, std::shared_ptr<solidity::assembly::AsmAnalysisInfo>>
-parse(std::string const& _source, bool _julia = true);
-solidity::assembly::Block disambiguate(std::string const& _source, bool _julia = true);
-std::string format(std::string const& _source, bool _julia = true);
+parse(std::string const& _source, bool _yul = true);
+solidity::assembly::Block disambiguate(std::string const& _source, bool _yul = true);
+std::string format(std::string const& _source, bool _yul = true);
}
}
@@ -16,7 +16,7 @@
/**
* @date 2017
- * Common functions the iulia tests.
+ * Common functions the Yul tests.
*/
#pragma once